@@ -8,8 +8,8 @@ cmd_subfolder_grid = os.path.realpath(os.path.abspath(os.path.join(os.path.split
 if cmd_subfolder_grid not in sys.path:
     sys.path.insert(0, cmd_subfolder_grid)
 
-from parser import Parser
-from grid import Grid
+from .parser import Parser
+from .grid import Grid
 '''
 Objectif :
 Parser le bon environnement et retourner les qtables/rewtable a partir du nom passer au constructeur
