@@ -1,7 +1,9 @@
 from .turtleAgent import Turtle
 from .envBuilder import *
+from .generator import *
 # @DEBUG from .turtleAgent import Turtle
-# @DEBUG ffrom .envBuilder import *
+# @DEBUG from .envBuilder import *
+# @DEBUG from .generator import *
 import time
 import random
 from enum import Enum
